/* =============================================================== 
 This file starts from the dyadic data set ai_data.dta and goes through all results in the JHR paper.
 there are 3 interim files created:
	 beta.ster (1000 betas for bootstrapping)
	 epsilon.dta (1000 epsilons for bootstrapping)
	 data2.dta an interim data set allowing to bypass code and go directly to dyadic analysis
=================================================================== */
global iterations = 1000
di $iterations

capture log close
capture clear all
set more off
set memory 100m

global data 		.
global output		..\Output
global tables		..\TablesFigure
global figures		..\TablesFigure
		
		
use "$data\data.dta", clear

* CITE IN TEXT: SAMPLE SIZE FOR COMPLETE DATA SET:
* After dropping households that did not split or have missing or incomplete interviews, our sample conisists of 
* 3,173 households from 712 families, yielding 13,808 unique within-family pairwise combinations of households. 
preserve
	keep if SymStatus<=2 //
	count // total no. dyads
	sum nsize if firstpair==1 // this is average network size
	qui duplicates drop HHID, force
	count // made up of this many HHs (out of 3312 households from HHData, excl. special cases)

	* calculate how many people own everything and how many nothing:
	count if n_house==1 & n_land==1 & n_liv==1 & n_phone==1 & n_video==1 & n_vehic==1 & n_f4==1 & n_formaljob==1
	count if n_house==0 & n_land==0 & n_liv==0 & n_phone==0 & n_video==0 & n_vehic==0 & n_f4==0 & n_formaljob==0
	
	gen stayers  = si2c==1 if si2c~=.
	gen movers = si2c~=1 if si2c~=.
	gen total = 1 		  if si2c~=.
	
	collapse (sum) movers stayers total, by(dynasty)
	sum // 2.51 movers and 1.94 stayers for 4.45 splits.
	count // originating from 712 dynasties
restore

* CITE in TEXT regarding the effect of attrition: attriters had less communication with family. 
recode SymStatus (1/2=11) (3=12), gen(SymTemp)
tab talk SymTemp, col nof m
drop SymTemp

* CITE IN TEXT: SAMPLE SIZE FOR DATA OF PEOPLE NOT LIVING IN SAME LOCATION
preserve
	keep if SymStatus==1
	count // total no. dyads
	sum nsize if firstpair==1 // this is average network size
	qui duplicates drop HHID, force
	count // made up of this many HHs (out of 3312 households from HHData, excl. special cases)
	qui duplicates drop dynasty, force // originating from this many dynasties
	count
restore

* CITE IN TEXT: communication with people living in the same location is higher
tab talk SymStatus, col nof m

* IMPORTANT, WE ARE NOW GOING TO REVERT TO THE 3,173 HHs from 712 families in 13,808 dyads
* CITE (as this is N in the paper and 3,173 are the number of observations in the omega regressions) 
keep if SymStatus<=2
count

* DEFINE X-VARS COMPARING ESTIMATE WITH REALITY 
label define estimate 1"underestimate" 2"spot-on" 3"overestimate" 4"DK"
foreach i in house land liv phone video vehic f4 formaljob {
	gen 	x`i' = 1  if (g_`i'==0 & n_`i'==1) 		// underestimate
	replace x`i' = 2  if (g_`i'==n_`i') & g_`i'~=. & n_`i'~=.
	replace x`i' = 3  if (g_`i'==1 & n_`i'==0) //overestimate
	replace x`i' = 4  if  g_`i'==99 // DKs
	label values x`i' estimate
	}
label var xhouse 		"Owns house"
label var xland  		"Owns land"
label var xliv			"Owns livestock"
label var xphone		"Owns phone"
label var xvideo		"Owns TV"
label var xvehic		"Owns motorized vehicle"
label var xf4			"Completed O'level"
label var xformaljob 	"Has formal job"

* Counts of under, over and dk in separate categories 
egen xunderN	= anycount(xhouse xland	xliv xphone xvideo xvehic xf4 xformaljob), values(1) 
egen xoverN		= anycount(xhouse xland	xliv xphone xvideo xvehic xf4 xformaljob), values(3)
egen xdkN 		= anycount(xhouse xland xliv xphone xvideo xvehic xf4 xformaljob), values(4)
egen xanyN   	= anycount(xhouse xland	xliv xphone xvideo xvehic xf4 xformaljob), values(1 3 4)
for varlist xunderN xoverN xdkN xanyN: replace X = . if xhouse==. & xland==. & xliv==.
gen  xsumN 		= xoverN - xunderN  

label var xunderN	"$\#$ of underestimates"
label var xoverN	"$\#$ of overestimates "	
label var xdkN 		"$\#$ of dk"
label var xanyN 	"$\#$ of wrong estimates or DKs"
label var xsumN 	"Unweighted sum of misperceptions"
tab1 xunderN xoverN xdkN xanyN xsumN

* ensures all of the above variables are non-missig unless there was a big skip for being in same location
qui for varlist xhouse-xvehic: assert X!=. if BigSkip==0 // no missings for household in same location
qui for varlist xhouse-xvehic: assert X==. if BigSkip==1 // all missing if they skipped AI questions
qui for varlist xf4 xformaljob: assert X~=.			// except these questions, which came before the skip

*************************************************************************************************************
* TABLE 1: Underestimates, overestimates and correct estimates per asset
*************************************************************************************************************
tab Sym BigS // those 976 dyads with symmetrical same location and no big skip are those where there's
			// a discrepancy between i and j's report on location, e.g. i said same location, but j said different
			// this creates an asymmetry and we drop these - one of the reasons to drop is because we want to use
			// both OMEGAdr and OMEGArd in the same regression which is not possible with these dyads: they only have 1 half reporting the AI questions and the other half skipped
			// this all to say that we have to do this table only on symmetrical HHs
preserve
	keep if SymStatus==1 // see explanation above
	assert _N==9032 // CITE IN TEXT in footnote of Table1(label:UnderOver)
	tempfile data
	save `data'
	clear
	set obs 1
	tempfile temp
	gen str20 name = ""
	save `temp'

	use `data', clear
	local i = 1
	foreach var of varlist xf4 xformaljob xhouse xland xliv xphone xvideo xvehic {
		use `data', clear
		local lab: variable label `var'  /* <- save variable label in local `lab' */
		tab `var', gen(c_)
		collapse (sum) c_1-c_4, fast
		egen total = rsum(c_1-c_4)
		for varlist c_1-c_4: replace X = X/total
		drop total
		gen str20 name = "`lab'"
		order name
		gen serial = `i'
		local i = `i' + 1
		append using `temp'
		save `temp', replace
	}
	sort serial
	drop serial
	drop if name==""
	format c_1-c_4 %9.3fc
	tempfile temp
	outsheet using  `temp', replace delim("&") non noq
	filefilter `temp' "$tables\UnderOver.tex", from("\r") to("\BS\BS") replace
	assert r(occurrences)==_N
restore

*******************************************
* TABLE 2: WEIGHTS IN OMEGA (LASSO)********
*******************************************
* IMPORTANT, WE ARE NOW GOING TO REVERT TO THE 3,173 HHs from 712 families in 13,808 dyads
* CITE (as this is N in the paper and 3,173 are the number of observations in the omega regressions) 
use "$data\data.dta", clear
keep if SymStatus<=2
count
duplicates drop n_HHID, force
drop g_*
* change varnames with actuals to what guesses will be named in dyadic data
ren n_house g_house 
ren n_land  g_land
ren n_liv	g_liv
ren n_phone g_phone
ren n_video g_video
ren n_vehic g_vehic
ren n_formaljob g_formaljob
ren n_prim g_prim
ren n_f4 g_f4
foreach x of varlist g_house g_land g_liv g_phone g_video g_vehic g_formaljob g_f4  {
	assert `x'~=.
	* this generates Urban/Rural specific means (at HH level rather than dyad level as latter has weight=nsize) to replace the DKs later on
	sum `x' if n_urban==1 
	gen MeanUrban`x' = r(mean)
	sum `x' if n_urban==0 
	gen MeanRural`x' = r(mean)
	}

* LABEL
label var n_head_sex 	"Head is male"
label var n_head_agesq 	"Head age squared"
label var n_urban		"HH located in urban area"

label var n_urban 		"Urban"
label var g_f4			"Completed O'level"
label var g_formaljob 	"Has formal job"
label var g_house 		"Owns house"
label var g_land  		"Owns land"
label var g_liv			"Owns livestock"
label var g_phone		"Owns phone"
label var g_video		"Owns TV"
label var g_vehic		"Owns vehicle"

global OmControls 		n_urban n_head_sex n_head_age n_head_agesq n_m0_5k n_m6_15k n_m16_60k n_m61k n_f0_5k n_f6_15k n_f16_60k n_f61k	
global OmLevels			g_f4 g_formaljob g_house g_land g_liv g_phone g_video g_vehic  
macro drop OmInteractions

* CREATE ALL INTERACTIONS
unab vars: $OmLevels $OmControls   
local nvar : word count `vars'
forval i = 1/`nvar' {
  forval j = 1/`=`i'-1' {
	local x : word `i' of `vars'
	local y : word `j' of `vars'
	generate `x'X`y' = `x' * `y'
	local labx: variable label `x'
	local laby: variable label `y'
	label var `x'X`y' "`labx' * `laby'"
	global OmInteractions $OmInteractions `x'X`y'
  }
}
* count the number of variables considered
local nv : word count $OmInteractions
di `nv'

* landxhouse is dropped as everyone with house has land
drop g_landXg_house 
di "$OmInteractions"
global OmInteractions: subinstr global OmInteractions "g_landXg_house" ""
di "$OmInteractions"
global LASEXT $OmLevels $OmInteractions $OmControls 
lassoShooting n_lnconspc $LASEXT, lasiter(100) verbose(1) fdisplay(1) 
local SelExt `r(selected)' 
di "`SelExt'" 

* OMEGA REGS
reg n_lnconspc `SelExt'
estimates store regresultsR, title("Lasso Extended")
predict double h_lnconspc
predict double res, residuals

* MAKE TABLE 2 SUMMARIZING OMEGA WEIGHTS
estout  regresultsR using "$tables\OmegaWeights.tex", style(tex) varlabels(_cons Constant) label replace ///
		cells(b(star fmt(%9.3f)) t(par fmt(%9.3f))) stats(r2_a N, fmt(%9.3f %9.0g) labels("Adjusted R-squared"))      ///
		collabels(none) mlabels(none) starlevels(* 0.1 ** 0.05 *** 0.01) 

*******************************************************
* APPENDIX 2 TABLE OF DESCRIPTIVES AT HOUSHEOLD LEVEL *
*******************************************************
eststo desHH: estpost sum n_lnconspc n_urban g_f4 g_formaljob g_house g_land g_liv g_phone g_video g_vehic n_head_sex n_head_age /*n_head_ed*/    /// 
			n_m0_5k n_m6_15k n_m16_60k n_m61k n_f0_5k n_f6_15k n_f16_60k n_f61k	
estout desHH using "$tables\DescribeHHs.tex", label cells("mean(fmt(2)) sd(fmt(2))") ///
	replace style(tex)  mlabel(none)  collabels(none)

*******************************************
* SAVE 1000 DIFFERENT BOOTSTRAPPED OMEGAS *
*******************************************
* you need the betas and the epsilons
* coeff estimates are put in 'betas'
reg n_lnconspc `SelExt'
estimates save "$output\betas", replace // estimate #1 contain betas on actual sample (useful to have)
* residual esimates are put in `epsilons'
preserve
	gen est = 1
	keep n_HHID est res
	save "$output\epsilons", replace // est=1 contains epsilons for actual sample
restore
* now repeat this X times
global SelExt `SelExt' // needs to be global to use inside loop below
global i = 2 // i=1 is the regression on the full sample 
capture program drop myboot
program define myboot, rclass
	preserve 
		bsample
		reg n_lnconspc $SelExt
		estimates save "$output\betas", append
	restore
	preserve
		drop res
		predict double res, residuals
		gen est=$i
		global i = $i + 1
		keep n_HHID est res
		append using "$output\epsilons"
		save "$output\epsilons", replace
	restore
end
* the good thing about using simulate is that you can use the seed to make ensure replicability of the entire loop procedure
preserve
	simulate , reps($iterations) seed(45678): myboot // SET ITERATIONS HERE - also change reps below on line 932
restore

* clean up and save a HH level file containing means for the computation of location-specific values. Res is superfluous as also saved in epsilons.dta with res=1
preserve 
	keep n_HHID h_lnconspc res Mean* 
	isid n_HHID, sort
	tempfile h_lnconspc // pure prediction (as alternative to n_lnconspc term)
	save `h_lnconspc'
restore


****************************************
* DATA CONSTRUCTION AT DYADIC LEVEL  ***
****************************************
use "$data\data.dta", clear
keep if SymStatus<=2
count
* DEFINE X-VARS COMPARING ESTIMATE WITH REALITY 
label define estimate 1"underestimate" 2"spot-on" 3"overestimate" 4"DK"
foreach i in house land liv phone video vehic f4 formaljob {
	gen 	x`i' = 1  if (g_`i'==0 & n_`i'==1) 		// underestimate
	replace x`i' = 2  if (g_`i'==n_`i') & g_`i'~=. & n_`i'~=.
	replace x`i' = 3  if (g_`i'==1 & n_`i'==0) //overestimate
	replace x`i' = 4  if  g_`i'==99 // DKs
	label values x`i' estimate
	}
label var xhouse 		"Owns house"
label var xland  		"Owns land"
label var xliv			"Owns livestock"
label var xphone		"Owns phone"
label var xvideo		"Owns TV"
label var xvehic		"Owns motorized vehicle"
label var xf4			"Completed O'level"
label var xformaljob 	"Has formal job"

* Counts of under, over and dk in separate categories 
egen xunderN	= anycount(xhouse xland	xliv xphone xvideo xvehic xf4 xformaljob), values(1) 
egen xoverN		= anycount(xhouse xland	xliv xphone xvideo xvehic xf4 xformaljob), values(3)
egen xdkN 		= anycount(xhouse xland xliv xphone xvideo xvehic xf4 xformaljob), values(4)
egen xanyN   	= anycount(xhouse xland	xliv xphone xvideo xvehic xf4 xformaljob), values(1 3 4)
for varlist xunderN xoverN xdkN xanyN: replace X = . if xhouse==. & xland==. & xliv==.
gen  xsumN 		= xoverN - xunderN  

label var xunderN	"$\#$ of underestimates"
label var xoverN	"$\#$ of overestimates "	
label var xdkN 		"$\#$ of dk"
label var xanyN 	"$\#$ of wrong estimates or DKs"
label var xsumN 	"Unweighted sum of misperceptions"
tab1 xunderN xoverN xdkN xanyN xsumN

* ensures all of the above variables are non-missig unless there was a big skip for being in same location
qui for varlist xhouse-xvehic: assert X!=. if BigSkip==0 // no missings for household in same location
qui for varlist xhouse-xvehic: assert X==. if BigSkip==1 // all missing if they skipped AI questions
qui for varlist xf4 xformaljob: assert X~=.			// except these questions, which came before the skip

* merge in conspc hat, residuals and Mean*
merge m:1 n_HHID using `h_lnconspc', nogen assert(3)

*** PUT DKs TO LOCATION-SENSITIVE SAMPLE MEANS (AS THAT WOULD BE BEST GUESS); NOTE THIS PUTS DUMMIES TO VALUES THAT DON'T EXIST; ALTERNATIVELY PLACE AT MEDIAN
assert inlist(n_urban,0,1)
foreach x of varlist g_house g_land g_liv g_phone g_video g_vehic g_f4 g_formaljob {
	replace `x'=MeanUrban`x' if `x'==99 & n_urban==1
	replace `x'=MeanRural`x' if `x'==99 & n_urban==0
}
drop Mean*
for varlist ?_house ?_land ?_phone ?_video ?_vehic ?_urban ?_formaljob ?_f4: tab X, m

* RECREATE ALL INTERACTIONS 
* LABEL
label var n_head_sex 	"Head is male"
label var n_head_agesq 	"Head age squared"
label var n_urban		"HH located in urban area"

label var n_urban 		"Urban"
label var g_f4			"Completed O'level"
label var g_formaljob 	"Has formal job"
label var g_house 		"Owns house"
label var g_land  		"Owns land"
label var g_liv			"Owns livestock"
label var g_phone		"Owns phone"
label var g_video		"Owns TV"
label var g_vehic		"Owns vehicle"
* INTERACT
unab vars: $OmLevels $OmControls   
local nvar : word count `vars'
forval i = 1/`nvar' {
  forval j = 1/`=`i'-1' {
	local x : word `i' of `vars'
	local y : word `j' of `vars'
	generate `x'X`y' = `x' * `y'
	local labx: variable label `x'
	local laby: variable label `y'
	label var `x'X`y' "`labx' * `laby'"
  }
}
*drop g_landXg_house // landxhouse is dropped as everyone with house has land

* CONSTRUCT OMEGA ON FULL SAMPLE
estimates restore regresultsR // or alternatively take first estimate from saved ones:
*estimates use "D:\KHDS\khds2010\ai\deleteme\savedestimates", number(1)
predict double 	  Pp 				// P' from manuscript
gen P        	= Pp + res 			// P  from manuscript
gen O  			= P  - n_lnconspc 	// omega from manuscript
gen Op 			= Pp - n_lnconspc 	// omega prime from manuscript
label var P 	"$ P_{ij}$"
label var Pp 	"$ P^{\prime }_{ij}$"
label var O 	"$\Omega_{ij}$"
label var Op 	"$\Omega^{\prime }_{ij}$"
gen absO  = abs(O)
gen absOp = abs(Op)
sum abs* 

*OMEGA TILDE (WITH LASSO SELECTION FROM HH-LEVEL FILE - DO LASSO ON DYADIC LEVEL?)
reg n_lnconspc $SelExt
estimates store regresultsT, title("beliefs regression")
predict double resi, residuals
generate Otilde=-resi
drop resi
label var Otilde "Residual from Dyadic Regression of j's pc cons on i's beliefs about j"

* FLIP-SIDE OF DYADS
tempfile temp
save `temp', replace
global FLIPME O Op Otilde P Pp giftsindum giftsin giftsoutdum giftsout xoverN xunderN xdkN xsumN g_ladder* ladder_self n_vehic n_phone n_MalePHHM n_FemalePHHM n_OrigHead n_OrigSpouse n_OrigSon n_OrigDaughter n_OrigOther 
keep HHID n_HHID $FLIPME
ren HHID tHHID
ren n_HHID HHID
ren tHHID n_HHID
for varlist $FLIPME: ren X n_X
ren n_n_vehic vehic
ren n_n_phone phone
ren n_n_MalePHHM 	 MalePHHM
ren n_n_FemalePHHM	 FemalePHHM
ren n_n_OrigHead 	 OrigHead 	
ren n_n_OrigSpouse	 OrigSpouse	
ren n_n_OrigSon		 OrigSon
ren n_n_OrigDaughter OrigDaughter
ren n_n_OrigOther	 OrigOther	


* RELABEL ALL FLIPPED VARS:
* note: the labels for the gifts* and g_ladder* vars are made in ai_data.do, those for O* and P* above
label var n_giftsin     "value gifts in from HHi, as reported by HHj"
label var n_giftsout	"value gifts out to HHi, as reported by HHj"
label var n_giftsindum  "any gifts in from HHi, as reported by HHj"
label var n_giftsoutdum	"any gifts out to HHi, as reported by HHj"

label var n_g_ladder9 	"On which rung of 9-step ladder does HHj place HHi?"
label var n_g_ladder123 "HHj places HHi on bottom rungs 1/2/3 of 9-step ladder"
label var n_g_ladder456 "HHj places HHi on middle rungs 4/5/6 of 9-step ladder"
label var n_g_ladder789 "HHj places HHi on top rungs 7/8/9 of 9-step ladder"
label var n_g_ladderdk  "HHj gives DK answer to ladder question regarding HHj"
label var n_ladder_self "On which rung of 9-step ladder does HHj place itself?"

label var n_P 		"$ P_{ji}$"
label var n_Pp 		"$ P^{\prime }_{ji}$"
label var n_O 		"$\Omega_{ji}$"
label var n_Op 		"$\Omega^{\prime }_{ji}$"
label var n_Otilde 	"Residual from Dyadic Regression of i's pc cons on j's beliefs about i"

label var n_xsumN 	"unweighted sum of misperceptions of donor about recipient"

label var vehic 	"i has vehicle"
label var phone		"i has phone"
label var MalePHHM	"Number of male PHHMs"
label var FemalePHHM "Number of female PHHMs"
label variable OrigHead 	"Head of original HH lives here"
label variable OrigSpouse	"No. of spouses of head in original HH living here"
label variable OrigSon		"No. of sons of head in original HH living here"
label variable OrigDaughter	"No. of daughthers of head in original HH living here"
label variable OrigOther	"No. of other relations to head in original HH living here"

* merge with the original data (ensure original data structure stays intact)
count
isid HHID n_HHID, sort
merge 1:1 HHID n_HHID using `temp', keep(2 3) nogen
gen family1 = real(substr(  HHID,-6,4))
gen family2  = real(substr(n_HHID,-6,4))
count if family1~=family2

* let's use S for xsumN
ren xsumN 	S
ren n_xsumN n_S

* GIFTS
* conditional gifts in levels
recode giftsin 		(0=.), gen(giftsinC)
recode n_giftsout	(0=.), gen(n_giftsoutC)
* conditional gifts in logs
gen lngiftsinC 		= ln(giftsin) 
gen n_lngiftsoutC 	= ln(n_giftsout)
* unconditional gifts in logs
recode lngiftsinC 	.=0, gen(lngiftsin) // unconditional
*recode n_lngiftsoutC .=0, gen(n_lngiftsin) // unconditional
*THERE was a mistake here
recode n_lngiftsoutC .=0, gen(n_lngiftsout) // unconditional

* A ladder9 variable without the DKs
gen g_ladderDK = (g_ladder9==99) if g_ladder9~=.
gen n_g_ladderDK = (n_g_ladder9==99) if n_g_ladder9~=.
recode g_ladder9 99=., gen(g_ladder9NODK)
recode g_ladder9     (99=0) (1/2=1) (3/9=0), gen(g_ladder12)
recode n_g_ladder9   (99=0) (1/2=1) (3/9=0), gen(n_g_ladder12)
recode g_ladder9   (99=0) (6/9=1) (1/5=0), gen(g_ladder6789)
recode n_g_ladder9 (99=0) (6/9=1) (1/5=0), gen(n_g_ladder6789)
recode g_ladder9   (99=0) (5/9=1) (1/4=0), gen(g_ladder56789)
recode n_g_ladder9 (99=0) (5/9=1) (1/4=0), gen(n_g_ladder56789)

* kmdismiss variable
gen kmdismiss =     (kmdis==.)
replace kmdis = 0 if kmdis==.

* Omega variables for the full and symmetric samples
gen O_full  		= O
gen Op_full 		= Op
gen S_full			= S
gen xdkN_full		= xdkN
replace O_full 		= 0 if BigSkip==1
replace Op_full		= 0 if BigSkip==1
replace S_full		= 0 if BigSkip==1
replace xdkN_full	= 0 if BigSkip==1
*
gen n_O_full  		= n_O
gen n_Op_full 		= n_Op
gen n_S_full		= n_S
gen n_xdkN_full		= n_xdkN
replace n_O_full 	= 0 if n_BigSkip==1
replace n_Op_full	= 0 if n_BigSkip==1
replace n_S_full	= 0 if n_BigSkip==1
replace n_xdkN_full	= 0 if n_BigSkip==1

* label nicely for reg output
label var sametribe 		"From same tribe"
label var samerelig 		"Same religious affiliation"
label var kmdis				"km distance"
label var kmdismiss			"km distance missing"
label var PC				"Parent-child link"
label var parent			"Parent lives in D"
label var child				"Child lives in D"
*
label var n_giftsoutdum		"D reports giving gift to R in past 12 months"
label var O					"$\Omega_{RD}$"
label var O_full			"$\Omega_{RD}$"
label var Op				"$\Omega_{RD}^{\prime}$"
label var Op_full			"$\Omega_{RD}^{\prime}$"
label var S					"unweighted OMEGA rd"
label var S_full			"unweighted OMEGA rd"
label var g_ladder123		"R places D on bottom rungs 1, 2, 3 of ladder"
label var g_ladder123		"R places D low on ladder ($\underline{L}_{RD}$)"
label var g_ladder456		"R places D on middle rungs 4, 5, 6 of ladder"
label var g_ladder789		"R places D on highest rungs 7, 8, 9 of ladder"
label var g_ladder789		"R places D high on ladder ($\overline{L}_{RD}$)"
label var g_ladderDK		"R answers DK on ladder question about D"
label var xdkN				"$#$ dk responses of R about D"
label var xdkN_full			"$#$ dk responses of R about D"
label var g_ladderdk		"R gives dk response about where D is on ladder"
label var lnconspc			"$ I_{R}$"
label var head_sex 			"R HH head is male"
label var head_age 			"R HH head age"
label var head_ed  			"R HH head years education"
label var m0_5k				"R HH No. Males 0-5 years"
label var m6_15k			"R HH No. Males 6-15 years"
label var m16_60k			"R HH No. Males 16-60 years"
label var m61k				"R HH No. Males 61+ years"
label var f0_5k				"R HH No. Females 0-5 years"
label var f6_15k			"R HH No. Females 6-15 years"
label var f16_60k			"R HH No. Females 16-60 years"
label var f61k				"R HH No. Females 61+ years"
*
label var n_O			"$\Omega_{DR}$"
label var n_O_full		"$\Omega_{DR}$"
label var n_Op			"$\Omega_{DR}^{\prime}$"
label var n_Op_full		"$\Omega_{DR}^{\prime}$"
label var n_S			"unweighted OMEGA dr"
label var n_S_full		"unweighted OMEGA dr"
label var n_g_ladder123	"D places R on bottom rungs 1, 2, 3 of ladder"
label var n_g_ladder123	"D places R low on ladder ($\underline{L}_{DR}$)"
label var n_g_ladder456	"D places R on middle rungs 4, 5, 6 of ladder"
label var n_g_ladder789	"D places R on highest rungs 7, 8, 9 of ladder"
label var n_g_ladder789	"D places R high on ladder ($\overline{L}_{DR}$)"
label var n_g_ladderDK	"D answers DK on ladder question about R"
label var n_xdkN		"$#$ dk responses of D about R"
label var n_xdkN_full	"$#$ dk responses of D about R"
label var g_ladderdk	"D gives dk response about where R is on ladder"
label var n_lnconspc	"$ I_{D}$"
label var n_head_sex 	"D HH head is male"
label var n_head_age 	"D HH head age"
label var n_head_ed  	"D HH head years education"
label var n_m0_5k		"D HH No. Males 0-5 years"
label var n_m6_15k		"D HH No. Males 6-15 years"
label var n_m16_60k		"D HH No. Males 16-60 years"
label var n_m61k		"D HH No. Males 61+ years"
label var n_f0_5k		"D HH No. Females 0-5 years"
label var n_f6_15k		"D HH No. Females 6-15 years"
label var n_f16_60k		"D HH No. Females 16-60 years"
label var n_f61k		"D HH No. Females 61+ years"

* Assert SymStatus is either 1 (for Omega) or 2 (sample added when using ladder)
assert inlist(SymStatus,1,2)
 
*
preserve
	keep if SymStatus==1
	tabstat O Op n_conspc, by(giftsindum) format(%9.3fc)
restore

* purge consumption of transfers
gen   conspcp 	= conspc 	- n_giftsout/hhsize
gen lnconspcp	= ln(conspcp)
label var lnconspcp "$ I_{R}$"
*
gen n_conspcp	= n_conspc + n_giftsout/n_hhsize 
gen n_lnconspcp = ln(n_conspcp)
label var n_lnconspcp "$ I_{D}$"

* save interim file
save "$data\data2.dta", replace








* NOTE: CODE BELOW CAN BE RUN BYPASSING CODE ABOVE BY STARTING FROM DATA2.DTA









************************************
************************************
* DATA ANALYSIS AT DYADIC LEVEL  ***
************************************
************************************
* CITED IN TEXT:  
use "$data\data2.dta", clear
sum O Op 		if Sym==1	// we obtain a mean (standard deviation) of 0.007 (0.315) for $\Omega$ and 0.002 (0.532) for $\Omega^{\prime }$
sum absO absOp  if Sym==1 	// The average of the absolute values of $\Omega$ and $\Omega ^{\prime }$ are 0.21 and 0.41
gen absOis0 = absO==0  if absO~=.
tab absOis0 if Sym==1   // $\Omega$ equals exactly zero in 30\% of dyads (used to be 27% with pre-review version of omega regs)
drop absOis0

*****************************************************
* FIGURE 1: DISTRIBUTIONS OF OMEGA AND OMGEGA PRIME *
*****************************************************
use "$data\data2.dta", clear
set more off
keep if SymStatus==1
label var O "Omega"
label var Op "Omega prime"
kdensity O  if  O>-1 &  O<1, xline(-.0129 .0267, lpattern(dash)) lpattern(full) lcolor(blue) lwidth(medthick) name(O, replace) title("") 	legend(off) note("")  bwidth(0.06) 
kdensity Op if Op>-1 & Op<1, xline(-.0199 .0232, lpattern(dash)) lpattern(full) lcolor(blue) lwidth(medthick) name(Op, replace) title("") 	legend(off) note("")  bwidth(0.06) 
graph combine O Op, note("Notes: The dashed vertical lines represent 95% confidence intervals around the mean" ///
						"        The point estimates of these means are .006 for Omega and .002 for Omega prime" ///
						"        30% of Omega observations = 0." ///
						"        X-axis truncated to span -1 to +1 for better rendition." ///
						"        Bandwidth=0.06.") ///
						ycommon xcommon
graph2tex, epsfile("$figures\kernelOOp")
window manage close graph _all

/* BOOTSTRAP RESULTS FOR MEAN AND SD OF OMEGA @ 1000 REPLICATIONS

Bootstrap results                               Number of obs      =      9032
                                                Replications       =      1000

------------------------------------------------------------------------------
             |   Observed   Bootstrap                         Normal-based
             |      Coef.   Std. Err.      z    P>|z|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
       Omean |   .0068814   .0100875     0.68   0.495    -.0128898    .0266527
         Osd |   .3150253    .006967    45.22   0.000     .3013701    .3286805
      Opmean |   .0016557   .0109841     0.15   0.880    -.0198726    .0231841
        Opsd |    .531788   .0109841    48.41   0.000     .5102596    .5533164
		
*/


**************************************************************
* TABLE 3 - Comparing Omega to subjective perceptions (label: ValidationLadder) ***
**************************************************************
use "$data\data2.dta", clear
keep if Sym==1
label var n_lnconspc  "log of $ j$'s actual consumption per capita"
label var g_ladder123 "$ i$ places $ j $ on bottom 3 rungs of 9-step ladder"
label var g_ladder789 "$ i$ places $ j $ on top 3 rungs of 9-step ladder"
label var g_ladderdk  "$ i$ gives DK answer to ladder question regarding $ j$"
*
xtreg O  g_ladder123 g_ladder789 g_ladderdk n_lnconspc n_xdkN xdkN, fe i(h1)
estimates store ladderO
xtreg Op g_ladder123 g_ladder789 g_ladderdk n_lnconspc n_xdkN xdkN, fe i(h1)
estimates store ladderOp
estout  ladderO ladderOp using "$tables\ValidationLadder.tex", style(tex) varlabels(_cons Constant) label replace ///
		cells(b(star fmt(%9.3f)) t(par fmt(%9.3f))) stats(N, fmt(%9.0g))      ///
           collabels(none) mlabels(none) drop(n_xdkN xdkN) starlevels(* 0.1 ** 0.05 *** 0.01)

**************************************
*  TABLE 4 - Correct expectations and distance
**************************************
use "$data\data2.dta", clear
keep if Sym==1
* deal with missing km and yearsapart information
tab kmdismiss // CITE: regressions include an indicator variable for 36 missing distance observations
sum yearsapart, d // 1 missing
replace kmdis=kmdis/100
replace yearsapart = r(mean) if yearsapart==.
* gen correct guess dummies
gen correctO = O==0
sum Op
gen correctOpHalfSD = inrange(Op,-0.5*r(sd),0.5*r(sd)) // centered around 0
tab1 correctO correctOp* // CITED IN TEXT 30% AND 39% ARE EQUAL TO ZERO IN THESE REGRESSIONS, RESPECTIVELY
* label
label var kmdis 		"Distance between HHs (100 km)"
label var n_move		"Moved away from village and vicinity"
label var yearsapart	"Number of years since $ i$ and $ j$ last lived together"
label var PC 			"Parent-child link"
label var n_urban		"$ j$ located in urban area"
label var wchere		"$ j$ has wife or child in same location as $ i$"
label var talkcode		"$ i$ and $ j$ communicated in the past 2 years"	
label var datedif		"Number of months between the HH interviews"
label var meallastyear  "Shared at least one meal in the past year"
label var meallastmonth	"Shared at least one meal in the past month"
global RHSPROBIT kmdis n_urban PC talkcode yearsapart meallastmonth kmdismiss n_xdkN xdkN
sum $RHSPROBIT
* estimate
dprobit correctO $RHSPROBIT
estimates store correctO
dprobit correctOpHalfSD $RHSPROBIT
estimates store correctOpHalfSD
* output
estout  correctO correctOpHalfSD using "$tables\ValidationProbit.tex", style(tex) varlabels(_cons Constant) label replace ///
		cells(b(star fmt(%9.4f)) t(par fmt(%9.3f))) stats(N, fmt(%9.0g))  margin nodiscrete    ///
           collabels(none) mlabels(none) drop(_cons kmdismiss n_xdkN xdkN) starlevels(* 0.1 ** 0.05 *** 0.01)


******************************************************************
*** BOOTSTRAPPED MEANS AND STANDARD DEVIATION OF O AND O PRIME ****
******************************************************************
use "$data\data2.dta", clear
keep if SymStatus==1
assert _N==9032
do "$data\aux_boot_summary.do"


*****************************
*  TRANSFER REGRESSIONS ****
*****************************
* timer 2 will track the complete run-through all regressions
capture timer clear 2
timer on 2

* ONLY THE $DYCTRL GLOBAL DOESN'T CHANGE - LET'S REDEFINE THE COMPLETE LIST FOR THE OTHERS TO AVOID MISTAKES
global DYCTRL sametribe samerelig kmdis kmdismiss parent child

* TABLE 9: LPM 
use "$data\data2.dta", clear
set more off
keep if SymStatus==1
assert _N==9032
global IN 	giftsindum
global OUT	n_giftsoutdum 
global R1 	O	n_O		xdkN n_xdkN															 
global R2 	Op	n_Op	xdkN n_xdkN      
global H1CTRL    lnconspc       head_sex   head_age   head_ed    m0_5k-f61k  	  phone	  vehic
global H2CTRL  n_lnconspc     n_head_sex n_head_age n_head_ed  n_m0_5k-n_f61k 	n_phone n_vehic
global DYCTRL sametribe samerelig kmdis kmdismiss parent child
do "$data\aux_boot_linear.do"
outsheet using  "$tables/Transfer1_Dummy.tex", replace delim("&") non noq
					/* THESE NUMBERS ARE CITED IN THE TEXT:
					SD of omega = 0.315
					From column 1 we see that if omega RD goes up with 1 SD then the likelihood of a transfer goes up by 0.075*0.315=0.02, or two percentage points.
					From column 2 we see that if omega RD goes up with 1 SD then the likelihood of a transfer goes up by 0.090*0.315=0.03, or three percentage points.
					
											col 1		col 
					marginal effect 		0.023625	0.02835
					incidence				0.2209		0.2031 (the one is of gifsindum, the other of n_giftsoutdum)
					ratio					11%			14%

					*/

* TABLE 10: LADDER - not bootstrapped
use "$data\data2.dta", clear
set more off
assert _N==13808
global IN 	giftsindum
global OUT	n_giftsoutdum 
global R4 	g_ladder123 g_ladder789 g_ladderDK n_g_ladder123 n_g_ladder789 n_g_ladderDK  
global H1CTRL    lnconspc       head_sex   head_age   head_ed    m0_5k-f61k  	  phone	  vehic
global H2CTRL  n_lnconspc     n_head_sex n_head_age n_head_ed  n_m0_5k-n_f61k 	n_phone n_vehic
global DYCTRL sametribe samerelig kmdis kmdismiss parent child
#delimit ;
twfe 		$IN   $DYCTRL 			$R4 , ids(h1 h2) 	cluster(h1 h2) ; est store m7, title(Eq (1)) ;
twfe 		$OUT  $DYCTRL 			$R4 , ids(h1 h2) 	cluster(h1 h2) ; est store m8, title(Eq (2)) ;
xtivreg2 	$IN   $DYCTRL	$H2CTRL $R4 , fe i(h1) 		cluster(h1 h2) ; est store m9, title(Eq (3)) ;
xtivreg2 	$OUT  $DYCTRL   $H1CTRL $R4 , fe i(h2) 		cluster(h1 h2) ; est store m10, title(Eq (4)) ;
#delimit cr
estout m7 m8 m9 m10 using "$tables/Transfer2_Ladder.tex",  ///
		keep( g_ladder123 g_ladder789 n_g_ladder123 n_g_ladder789 n_lnconspc lnconspc)  ///
		order(g_ladder123 g_ladder789 n_g_ladder123 n_g_ladder789 n_lnconspc lnconspc)  ///
		style(tex) varlabels(_cons Constant) label replace collabels(, none) mlabels(, none)   ///
		cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) starlevels(* 0.1 ** 0.05 *** 0.01)
			
* TABLE APPENDIX: VALUES (TABLE 9, DIFFERENT $IN AND $OUT)
use "$data\data2.dta", clear
set more off
keep if SymStatus==1
assert _N==9032
global IN 	lngiftsin
global OUT	n_lngiftsout	
global R1 	O	n_O		xdkN n_xdkN															 
global R2 	Op	n_Op	xdkN n_xdkN      
global H1CTRL    lnconspc       head_sex   head_age   head_ed    m0_5k-f61k  	  phone	  vehic
global H2CTRL  n_lnconspc     n_head_sex n_head_age n_head_ed  n_m0_5k-n_f61k 	n_phone n_vehic
global DYCTRL sametribe samerelig kmdis kmdismiss parent child
do "$data\aux_boot_linear.do"
outsheet using  "$tables/Transfer3_Value.tex", replace delim("&") non noq

* TABLE 12: NON-LINEAR - not bootstrapped 
use "$data/data2.dta", clear
keep if SymStatus==1
assert _N==9032

global IN     giftsindum
global OUT    n_giftsoutdum
global R1     O      n_O           xdkN n_xdkN                                                                                                   
global R2     Op     n_Op   xdkN n_xdkN      
global H1CTRL    lnconspc       head_sex   head_age   head_ed    m0_5k-f61k    phone	  vehic
global H2CTRL  n_lnconspc     n_head_sex n_head_age n_head_ed  n_m0_5k-n_f61k  	n_phone n_vehic
global DYCTRL sametribe samerelig kmdis kmdismiss parent child

foreach X of varlist O n_O Op n_Op xdkN n_xdkN  $H1CTRL $H2CTRL $DYCTRL {
       bys h1: egen m1_`X'=mean(`X') 
}
foreach X of varlist O n_O Op n_Op xdkN n_xdkN  $H1CTRL $H2CTRL $DYCTRL {
       bys h2: egen m2_`X'=mean(`X') 
}
global m1_CTRL       m1_xdkN m1_n_xdkN m1_sametribe m1_samerelig m1_kmdis m1_kmdismiss m1_parent m1_child  m1_n_lnconspc m1_n_head_sex m1_n_head_age m1_n_head_ed m1_n_m0_5k m1_n_m6_15k m1_n_m16_60k m1_n_m61k m1_n_f0_5k m1_n_f6_15k m1_n_f16_60k m1_n_f61k  m1_n_phone m1_n_vehic
global m2_CTRL       m2_xdkN m2_n_xdkN m2_sametribe m2_samerelig m2_kmdis m2_kmdismiss m2_parent m2_child    m2_lnconspc     m2_head_sex   m2_head_age   m2_head_ed   m2_m0_5k   m2_m6_15k   m2_m16_60k   m2_m61k   m2_f0_5k   m2_f6_15k   m2_f16_60k   m2_f61k  m2_phone m2_vehic
#delimit ;
clogit        $IN  O n_O                               xdkN n_xdkN $DYCTRL $H2CTRL, group(h1) cl(family1) ; est store m1, title(Eq (1));
clogit        $OUT O n_O                               xdkN n_xdkN $DYCTRL $H1CTRL, group(h2) cl(family2) ; est store m2, title(Eq (2));
meprobit      $IN  O n_O m1_O m1_n_O                   xdkN n_xdkN $DYCTRL $H1CTRL $H2CTRL $m1_CTRL  ||family1: || HHID: ; est store m3, title(Eq (3));
meprobit      $OUT O n_O m2_O m2_n_O                   xdkN n_xdkN $DYCTRL $H1CTRL $H2CTRL $m2_CTRL  ||family1: || n_HHID: ; est store m4, title(Eq (4));

clogit        $IN  Op n_Op                                    xdkN n_xdkN $DYCTRL $H2CTRL, group(h1) cl(family1) ; est store m5, title(Eq (5));
clogit        $OUT Op n_Op                                    xdkN n_xdkN $DYCTRL $H1CTRL, group(h2) cl(family2) ; est store m6, title(Eq (6));
meprobit      $IN  Op n_Op m1_Op m1_n_Op        xdkN n_xdkN $DYCTRL $H1CTRL $H2CTRL $m1_CTRL  ||family1: || HHID: ; est store m7, title(Eq (7));
meprobit      $OUT Op n_Op m2_Op m2_n_Op        xdkN n_xdkN $DYCTRL $H1CTRL $H2CTRL $m2_CTRL  ||family1: || n_HHID: ; est store m8, title(Eq (8));
#delimit cr

estout m1 m2 m3 m4 m5 m6 m7 m8 using "$tables\Transfer4_NonLinear.tex",  ///
       keep( O n_O Op n_Op n_lnconspc lnconspc)  ///
       order(O n_O Op n_Op n_lnconspc lnconspc)  ///
       style(tex) varlabels(_cons Constant) label replace collabels(, none) mlabels(, none)   ///
       cells(b(star fmt(%9.3f)) t(par fmt(%9.2f))) starlevels(* 0.1 ** 0.05 *** 0.01)

	
* TABLE APPENDIX: PURGED (TABLE 9, DIFFERENT $H1CTRL AND $H2CTRL)
use "$data\data2.dta", clear
set more off
keep if SymStatus==1
assert _N==9032
global IN 	giftsindum
global OUT	n_giftsoutdum 
global R1 	O	n_O		xdkN n_xdkN															 
global R2 	Op	n_Op	xdkN n_xdkN      
global H1CTRL   lnconspcp      head_sex   head_age   head_ed    m0_5k-f61k        phone	  vehic
global H2CTRL n_lnconspcp    n_head_sex n_head_age n_head_ed  n_m0_5k-n_f61k    n_phone n_vehic
global DYCTRL sametribe samerelig kmdis kmdismiss parent child
do "$data\aux_boot_linear.do"
outsheet using  "$tables/Transfer5_Purged.tex", replace delim("&") non noq

* TABLE APPENDIX: SAME LOCATION (TABLE 9, DIFFERENT $R1 AND $R2)
use "$data\data2.dta", clear
set more off
assert _N==13808
global IN 	giftsindum
global OUT	n_giftsoutdum 
global R1 	O_full	n_O_full		xdkN n_xdkN															 
global R2 	Op_full	n_Op_full		xdkN n_xdkN  
global H1CTRL    lnconspc       head_sex   head_age   head_ed    m0_5k-f61k  	  phone	  vehic
global H2CTRL  n_lnconspc     n_head_sex n_head_age n_head_ed  n_m0_5k-n_f61k 	n_phone n_vehic
global DYCTRL sametribe samerelig kmdis kmdismiss parent child
do "$data\aux_boot_linear.do"
outsheet using  "$tables/Transfer6_SameLocation.tex", replace delim("&") non noq

timer off 2
di r(t2)/60


*********************************************
* TABLE APPENDIX: DYADIC LEVEL DESCRIPTIVES *
*********************************************
global H1CTRL    lnconspc       head_sex   head_age   head_ed    m0_5k-f61k  	  phone	  vehic
use "$data\data2.dta", clear
eststo s1: estpost sum n_giftsoutdum O n_O Op n_Op g_ladder123 g_ladder789 g_ladderDK n_g_ladder123 n_g_ladder789 n_g_ladderDK $H1CTRL PC kmdis if SymStatus==1
eststo s2: estpost sum n_giftsoutdum O n_O Op n_Op g_ladder123 g_ladder789 g_ladderDK n_g_ladder123 n_g_ladder789 n_g_ladderDK $H1CTRL PC kmdis 
estout s1 s2 using "$tables/DescribeDyads.tex", label cells("mean(fmt(2)) sd(fmt(2))") replace style(tex)  mlabel(none)  collabels(none)
	


	
	
	
	
	
*****************************************************
*****************************************************
* SOME FURTHER DESCRIPTIVES NOTED IN THE MANUSCRIPT	*
*****************************************************
*****************************************************
		
*******************************************
*  DESCRIPTION HH LOCATION BY FAMILY TIE **
*******************************************
use "$data\data2.dta"
bys   HHID: gen   firstobs = (_n==1)

tab T0Qd if firstobs==1
bys OrigHead : tab T0Qd if firstobs==1

*Check if location differs whether household has sons or daughters of the previous Head
*not in general
tab T0Qd if firstobs==1 & OrigSon>=1
tab T0Qd if firstobs==1 & OrigDaughter>=1

*differences between split- off households with sons or daugters of former head not living with their parents
tab T0Qd if firstobs==1 & OrigDaughter>=1 & OrigHead==0 & OrigSpouse==0
tab T0Qd if firstobs==1 & OrigSon>=1 & OrigHead==0 & OrigSpouse==0


**********************************************
* INTERACTIONS WITH PARENT CHILD LINK (PC) ***
**********************************************
use "$data\data2.dta",clear
keep if SymStatus==1 

gen OintC=O*child
gen OintP=O*parent
gen n_OintC=n_O*child
gen n_OintP=n_O*parent
gen lncons_intC=lnconspc*child
gen lncons_intP=lnconspc*parent
gen n_lncons_intC=n_lnconspc*child
gen n_lncons_intP=n_lnconspc*parent

label var OintC "$\Omega_{RD} child_{D}$"
label var OintP "$\Omega_{RD} parent_{D}$"
label var n_OintC "$\Omega_{DR} child_{D}$"
label var n_OintP "$\Omega_{DR} parent_{D}$"

gen OpintC=Op*child
gen OpintP=Op*parent
gen n_OpintC=n_Op*child
gen n_OpintP=n_Op*parent
label var OpintC "$\Omega_{RD}^{\prime}  child_{D}$"
label var OpintP "$\Omega_{RD}^{\prime}  parent_{D}$"
label var n_OpintC "$\Omega_{DR}^{\prime} child_{D}$"
label var n_OpintP "$\Omega_{DR}^{\prime} parent_{D}$"

global IN 	giftsindum
global OUT	n_giftsoutdum 
global INV 	lngiftsin
global OUTV	n_lngiftsout
global R1 	O	n_O	OintC OintP	n_lncons_intC n_lncons_intP xdkN n_xdkN															 
global R2 	Op	n_Op OpintC OpintP	n_lncons_intC n_lncons_intP xdkN n_xdkN  	                                                    	
global R3 	S	n_S 	xdkN n_xdkN                                                     	
global R4 	g_ladder123 g_ladder789 g_ladderDK n_g_ladder123 n_g_ladder789 n_g_ladderDK  
global R5 	Otilde	n_Otilde		xdkN n_xdkN				
global R6 	O_full	n_O_full		xdkN n_xdkN															 
global R7 	Op_full	n_Op_full		xdkN n_xdkN  
			
global H1CTRL    lnconspc       head_sex   head_age   head_ed    m0_5k-f61k  	  phone	  vehic
global H2CTRL  n_lnconspc     n_head_sex n_head_age n_head_ed  n_m0_5k-n_f61k 	n_phone n_vehic
global H1CTRLP   lnconspcp      head_sex   head_age   head_ed    m0_5k-f61k       phone	  vehic
global H2CTRLP n_lnconspcp    n_head_sex n_head_age n_head_ed  n_m0_5k-n_f61k   n_phone n_vehic

global DYCTRL sametribe samerelig kmdis kmdismiss   parent child


twfe 		$IN   $DYCTRL 		$R1 , ids(h1 h2)	cluster(h1 h2) 				 
twfe 		$OUT  $DYCTRL 		$R1 , ids(h1 h2)	cluster(h1 h2) 				 
xtivreg2 	$IN   $DYCTRL	$H2CTRL $R1 , fe i(h1) 		cluster(h1 h2) 	
xtivreg2 	$IN   $DYCTRL	$H2CTRL $R2 , fe i(h1) 		cluster(h1 h2) 	
xtivreg2 	$OUT   $DYCTRL  $H1CTRL $R1 , fe i(h2) 		cluster(h1 h2) 	
xtivreg2 	$OUT   $DYCTRL  $H1CTRL $R2 , fe i(h2) 		cluster(h1 h2) 	




